==> ejc-zzyjlabor-impl-3.0.0-20231229.010926-35-sources.jar: com/ejianc/business/other/xiaoshi/bean/XiaoShiLogEntity.java <==
package com.ejianc.business.other.xiaoshi.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 小视-日志
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_xiaoshi_log")
public class XiaoShiLogEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="interface_type")
    private String interfaceType; // 接口类型
    @TableField(value="interface_name")
    private String interfaceName; // 接口
    @TableField(value="res_code")
    private String resCode; // 返回码
    @TableField(value="res_msg")
    private String resMsg; // 返回信息
    @TableField(value="res_data")
    private String resData; // 返回数据
    @TableField(value="input_params")
    private String inputParams; // 入参
    
    
    

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getInterfaceType() {
        return interfaceType;
    }

    public void setInterfaceType(String interfaceType) {
        this.interfaceType = interfaceType;
    }
    public String getInterfaceName() {
        return interfaceName;
    }

    public void setInterfaceName(String interfaceName) {
        this.interfaceName = interfaceName;
    }
    public String getResCode() {
        return resCode;
    }

    public void setResCode(String resCode) {
        this.resCode = resCode;
    }
    public String getResMsg() {
        return resMsg;
    }

    public void setResMsg(String resMsg) {
        this.resMsg = resMsg;
    }
    public String getResData() {
        return resData;
    }

    public void setResData(String resData) {
        this.resData = resData;
    }
    public String getInputParams() {
        return inputParams;
    }

    public void setInputParams(String inputParams) {
        this.inputParams = inputParams;
    }
    
}

==> ejc-zzyjlabor-impl-3.0.0-20240111.082842-40-sources.jar: com/ejianc/business/other/xiaoshi/bean/XiaoShiLogEntity.java <==
package com.ejianc.business.other.xiaoshi.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 小视-日志
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_xiaoshi_log")
public class XiaoShiLogEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="interface_type")
    private String interfaceType; // 接口类型
    @TableField(value="interface_name")
    private String interfaceName; // 接口
    @TableField(value="res_code")
    private String resCode; // 返回码
    @TableField(value="res_msg")
    private String resMsg; // 返回信息
    @TableField(value="res_data")
    private String resData; // 返回数据
    @TableField(value="input_params")
    private String inputParams; // 入参
    @TableField(value="log_type")
    private String logType; // 日志平台
    
    

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getInterfaceType() {
        return interfaceType;
    }

    public void setInterfaceType(String interfaceType) {
        this.interfaceType = interfaceType;
    }
    public String getInterfaceName() {
        return interfaceName;
    }

    public void setInterfaceName(String interfaceName) {
        this.interfaceName = interfaceName;
    }
    public String getResCode() {
        return resCode;
    }

    public void setResCode(String resCode) {
        this.resCode = resCode;
    }
    public String getResMsg() {
        return resMsg;
    }

    public void setResMsg(String resMsg) {
        this.resMsg = resMsg;
    }
    public String getResData() {
        return resData;
    }

    public void setResData(String resData) {
        this.resData = resData;
    }
    public String getInputParams() {
        return inputParams;
    }

    public void setInputParams(String inputParams) {
        this.inputParams = inputParams;
    }

    public String getLogType() {
        return logType;
    }

    public void setLogType(String logType) {
        this.logType = logType;
    }
}
